"""(c) All rights reserved. ECOLE POLYTECHNIQUE FEDERALE DE LAUSANNE, Switzerland, VPSI, 2017"""
CONSTANTS = {
    "EPFL_LDAP_SERVER_FOR_SEARCH": "ldap.epfl.ch",
    "EPFL_LDAP_SERVER_FOR_AUTHENTICATE": "scoldap.epfl.ch",
    "EPFL_LDAP_BASE_DN": "o=epfl,c=ch",
    "EPFL_LDAP_USE_SSL": True,
    "EPFL_LDAP_USER_SEARCH_ATTR": "uid",
    "EPFL_LDAP_TEST_CORRECT_USERNAME": "kermit",
}
